import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// GitHub Dark theme color definitions
const base00 = '#0d1117', // Background
base01 = '#c9d1d9', // Foreground
base02 = '#003d73', // Selection and Selection Match
base03 = '#8b949e', // Comment and Bracket color
base04 = '#c9d1d9', // Caret color (reusing foreground for consistency)
base05 = '#7ee787', // TagName, Name, Quote
base06 = '#d2a8ff', // ClassName, PropertyName, Heading, Strong, Emphasis
base07 = '#79c0ff', // VariableName, AttributeName, Number, Operator
base08 = '#ff7b72', // Keyword, TypeName, TypeOperator
base09 = '#a5d6ff', // String, Meta, Regexp
base0A = '#ffdcd7', // Deleted text color
base0B = '#ffeef0', // Deleted background color
base0C = '#ffab70', // Atom, Bool, Special VariableName
invalid = '#f97583'; // Invalid color
const highlightBackground = '#36334280', // Line highlight with some opacity
tooltipBackground = base01, // Tooltips using foreground color
cursor = base04, // Caret color
selection = base02; // Selection color
// Define the editor theme styles for GitHub Dark.
const githubDarkTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: base00,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: base02, // Use the selection color for search matches
        color: base01, // Ensure the text color contrasts with the background
        outline: `1px solid ${base04}`, // Highlight with a subtle outline
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base08, // Use a distinct color for the selected search match
        color: base00, // Invert color for high visibility
        outline: `1px solid ${base04}`,
    },
    '.cm-panels': {
        backgroundColor: base00, // Use the main background color for consistency
        color: base01,
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: '2px solid black',
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: '2px solid black',
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
    },
    '.cm-gutters': {
        backgroundColor: base00, // Gutter background using the main background
        color: base03, // Use comment color for gutter foreground
    },
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
    },
}, { dark: true });
// Define the highlighting style for code in the GitHub Dark theme.
const githubDarkHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: [/*@__PURE__*/tags.standard(tags.tagName), tags.tagName], color: base05 },
    { tag: [tags.comment, tags.bracket], color: base03 },
    { tag: [tags.className, tags.propertyName], color: base06 },
    { tag: [tags.variableName, tags.attributeName, tags.number, tags.operator], color: base07 },
    { tag: [tags.keyword, tags.typeName, tags.typeOperator], color: base08 },
    { tag: [tags.string, tags.meta, tags.regexp], color: base09 },
    { tag: [tags.name, tags.quote], color: base05 },
    { tag: [tags.heading, tags.strong], color: base06, fontWeight: 'bold' },
    { tag: [tags.emphasis], color: base06, fontStyle: 'italic' },
    { tag: [tags.deleted], color: base0A, backgroundColor: base0B },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base0C },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
    { tag: tags.invalid, color: invalid },
]);
// Extension to enable the GitHub Dark theme (both the editor theme and the highlight style).
const githubDark = [
    githubDarkTheme,
    /*@__PURE__*/syntaxHighlighting(githubDarkHighlightStyle),
];

export { githubDark, githubDarkHighlightStyle, githubDarkTheme };
